import subprocess, os

def get_soup(url):
    cwd = os.getcwd()
    javasoup_js = """const puppeteer = require('puppeteer');

function getHtml(url){
    try {
        (async () => {
            const browser = await puppeteer.launch();
            const page = await browser.newPage();
            try {
                await page.goto(url, {
                    waitUntil: 'networkidle0'
                });
            } catch (error) {
                console.log(error);
                process.exit(1);
            }
            try {
                const data = await page.content();
                console.log(data);
            } catch (error) {
                console.log(error);
                process.exit(1);
            }

            try {
                await browser.close();
            } catch (error) {
                console.log(error);
                process.exit(1);
            }
        })();
    } catch (error) {
        console.log(error);
        process.exit(1);
    }
}

getHtml(process.argv[2]);"""
    f = open(f'{cwd}/javasoup.js', 'w')
    f.write(javasoup_js)
    f.close()
    get_content = subprocess.run([f'node javasoup.js {url}'], stdout=subprocess.PIPE, stderr=subprocess.DEVNULL, text=True, shell=True)
    subprocess.run([f"rm {cwd}/javasoup.js"], stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL, text=True, shell=True)
    return get_content.stdout


from distutils.core import setup
setup(
  name = 'javasoup',        
  packages = ['javasoup'],  
  version = '0.3',    
  license='MIT',       
  description = 'Simple python library that uses puppeteer to pull HTML from a loaded SPA (REQUIRES NODE, NPM, AND PUPPETEER)',   
  author = 'rs0n',                  
  author_email = 'rs0n.evolv3@gmail.com',     
  url = 'https://github.com/R-s0n/javasoup',  
  download_url = 'https://github.com/R-s0n/javasoup/archive/refs/tags/v_01.tar.gz',  
  keywords = ['webscraping', 'beautifulsoup', 'soup'],  
  install_requires=[],
  classifiers=[
    'Development Status :: 3 - Alpha',     
    'Intended Audience :: Developers',     
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',  
    'Programming Language :: Python :: 3',   
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)